| Title: | A 'shiny' Application for Active Learning Instruction in Introductory Quantitative Genetics |
|---|---|
| Description: | A 'shiny' application for teaching introductory quantitative genetics and plant breeding through interactive simulations. The application relies on established plant breeding and quantitative genetic theory found in Falconer and Mackay (1996, ISBN:0582243025) and Bernardo (2010, ISBN:978-0972072427). |
| Authors: | Jeffrey Neyhart [aut, cre] (ORCID: <https://orcid.org/0000-0002-1991-5310>) |
| Maintainer: | Jeffrey Neyhart <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-14 08:57:02 UTC |
| Source: | https://github.com/neyhartj/qgshiny |
Runs the 'shiny' application interactively.
run_qgshiny(display.mode = c("normal", "showcase"))run_qgshiny(display.mode = c("normal", "showcase"))
display.mode |
The mode in which to display the application. If |
if (interactive()) { run_qgshiny() }if (interactive()) { run_qgshiny() }