Welcome to ClientVPS Mirrors

Help for package qgshiny
Title: A 'shiny' Application for Active Learning Instruction in Introductory Quantitative Genetics
Version: 0.1.0
Description: A 'shiny' application for teaching introductory quantitative genetics and plant breeding through interactive simulations. The application relies on established plant breeding and quantitative genetic theory found in Falconer and Mackay (1996, ISBN:0582243025) and Bernardo (2010, ISBN:978-0972072427).
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
Depends: R (≥ 3.5.0)
Imports: stats, shiny, rmarkdown
NeedsCompilation: no
Packaged: 2020-07-01 14:14:51 UTC; jln54
Author: Jeffrey Neyhart ORCID iD [aut, cre]
Maintainer: Jeffrey Neyhart <neyhartje@gmail.com>
Repository: CRAN
Date/Publication: 2020-07-02 11:20:02 UTC

Run the application

Description

Runs the 'shiny' application interactively.

Usage

run_qgshiny(display.mode = c("normal", "showcase"))

Arguments

display.mode

The mode in which to display the application. If "showcase", application code is displayed along with the output. If "normal" (default), the code is hidden.

Examples

if (interactive()) {
 run_qgshiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.